import pytest
from subprocess import check_output, check_call
from os.path import dirname, join

import json

@pytest.mark.usefixtures('sim_hocr_file')
@pytest.mark.usefixtures('sim_english_pagenumber_json_file')

def test_hocr_pagenumbers(sim_hocr_file, sim_english_pagenumber_json_file):
    sim_hocr_file = str(sim_hocr_file)
    basedir = dirname(sim_hocr_file)

    pagenumber_json_file = join(basedir, 'pagenumbers.json')

    check_call(['hocr-pagenumbers', '--density-threshold-pass-two', '0.1',
                '-f', sim_hocr_file, '-o', pagenumber_json_file])

    new = open(pagenumber_json_file, 'rb').read()
    old = open(sim_english_pagenumber_json_file, 'rb').read()

    assert old == new



import pytest
from subprocess import check_output, check_call
from os.path import dirname, join

import json

@pytest.mark.usefixtures('pdf_file')
@pytest.mark.usefixtures('pdf_metadata_file')
@pytest.mark.usefixtures('pdf_chocr_file')

def test_pdf_to_hocr(pdf_file, pdf_metadata_file, pdf_chocr_file):
    pdf_file = str(pdf_file)
    pdf_metadata_file = str(pdf_metadata_file)
    pdf_chocr_file = str(pdf_chocr_file)

    basedir = dirname(pdf_file)

    pdf_chocr_out = join(basedir, 'pdf-chocr.html')

    pdf_chocr = check_output(['pdf-to-hocr', '-J', pdf_metadata_file, '-f', pdf_file])

    orig_text = check_output(['xmllint', '--format', pdf_chocr_file])
    pdf_chocr = check_output(['xmllint', '--format', '-'], input=pdf_chocr)

    assert pdf_chocr == orig_text



import pytest
from subprocess import check_output, check_call
from os.path import dirname, join

import json

@pytest.mark.usefixtures('sim_hocr_file')

def test_split_combine_plaintext(sim_hocr_file):
    sim_hocr_file = str(sim_hocr_file)
    basedir = dirname(sim_hocr_file)

    split_pages = join(basedir, 'split-%06d.html')
    split_pages_g = join(basedir, 'split-*.html')
    combined_file = join(basedir, 'combined.html')

    check_call(['hocr-split-pages', '-f', sim_hocr_file, '-o', split_pages])
    combined_text = check_output(['hocr-combine-stream', '-g', split_pages_g])

    with open(combined_file, 'wb+') as f:
        f.write(combined_text)

    plaintext = check_output(['hocr-text', '-f', sim_hocr_file])
    new_plaintext = check_output(['hocr-text', '-f', combined_file])

    assert plaintext == new_plaintext




import pytest
from subprocess import check_output, check_call
from os.path import dirname, join

import json

@pytest.mark.usefixtures('abbyy_file')
@pytest.mark.usefixtures('abbyy_to_hocr_file')

def test_pdf_to_hocr(abbyy_file, abbyy_to_hocr_file):
    abbyy_file = str(abbyy_file)
    abbyy_to_hocr_file = str(abbyy_to_hocr_file)

    basedir = dirname(abbyy_file)

    chocr_out = join(basedir, 'chocr.html')

    chocr_data = check_output(['abbyy-to-hocr', '-f', abbyy_file])

    orig_chocr = check_output(['xmllint', '--format', abbyy_to_hocr_file])
    chocr_data = check_output(['xmllint', '--format', '-'], input=chocr_data)

    assert orig_chocr == chocr_data
